==> go.php?file=SayAnnouncer7.300.zip: SayAnnouncer/SayAnnouncer.lua <==
﻿function SA_OnLoad()

	sa_version=7.300

	SA_frame:RegisterEvent("CHAT_MSG_ADDON")
	SA_frame:RegisterEvent("CHAT_MSG_SAY")
	SA_frame:RegisterEvent("CHAT_MSG_INSTANCE_CHAT")
	SA_frame:RegisterEvent("CHAT_MSG_YELL")
	SA_frame:RegisterEvent("PLAYER_ENTERING_WORLD")

	sayelldelay=GetTime()
	sayelldelay2=GetTime()
	saydelayfornames=GetTime()+15
	if SA_whitelist==nil then SA_whitelist={} end

	sa_waitfilter={0,0}

end


function SA_OnUpdate()

if GetTime()>saydelayfornames then
saydelayfornames=nil

local num=GetNumGuildMembers()
for i=1,num do
	local name, rank, rankIndex=GetGuildRosterInfo(i)
	if (rankIndex==0 or rankIndex==1) and name then
		local bil=0
		for j=1,#SA_whitelist do
			if string.lower(SA_whitelist[j])==string.lower(name) then
				bil=1
			end
		end
		if bil==0 then
			table.insert(SA_whitelist,name)
		end
	end
end
end
end


function SA_OnEvent(self,event,...)

local arg1, arg2, arg3,arg4 = ...

if event=="PLAYER_ENTERING_WORLD" then
if type(RegisterAddonMessagePrefix) == "function" then
RegisterAddonMessagePrefix ("SAver")
RegisterAddonMessagePrefix ("SAYell")
end
end

if event == "CHAT_MSG_SAY" then
if arg2 and arg2==UnitName("player") then
	sa_waitfilter[1]=GetTime()+1.5
end
end

if event == "CHAT_MSG_YELL" then
if arg2 and arg2==UnitName("player") then
	sa_waitfilter[2]=GetTime()+1.5
end
end

if event == "CHAT_MSG_ADDON" then

if arg1=="SAver" and arg4 then
local bil=0
SendAddonMessage("SAver2", bil..sa_version, "WHISPER", arg4)
end

if arg1=="SAYell" and arg3=="WHISPER" and GetTime()>sayelldelay then
local bilname=0
for i=1,#SA_whitelist do
	if string.lower(SA_whitelist[i])==string.lower(arg4) then
		bilname=1
	end
end

if bilname==0 then
	for i = 1,GetNumGroupMembers() do local name,rank = GetRaidRosterInfo(i)
		if (rank > 0 and arg2==name) then
			bilname=1
		end
	end
end

local _,a2=IsInInstance()
if arg2 and bilname==1 and a2 and a2=="raid" and UnitInRaid(arg4) and UnitAffectingCombat("player") then
	local text=""
	local chat=""
	local block=0
	local vaj=0
	if string.find(arg2, "+0!") then
		text=string.sub(arg2,1,string.find(arg2,"+0!")-1)
	end
	if string.find(arg2, "+1!") then
		chat=string.sub(arg2,string.find(arg2,"+0!")+3,string.find(arg2,"+1!")-1)
	end
	if string.find(arg2, "+2!") then
		block=tonumber(string.sub(arg2,string.find(arg2,"+1!")+3,string.find(arg2,"+2!")-1))
	end
	if string.find(arg2, "+3!") then
		vaj=tonumber(string.sub(arg2,string.find(arg2,"+2!")+3,string.find(arg2,"+3!")-1))
	end
	if string.len(text)>1 and string.len(chat)>1 then
		if chat=="say" or chat=="yell" then
			if ((chat=="say" and GetTime()<sa_waitfilter[1]) or (chat=="yell" and GetTime()<sa_waitfilter[2])) and vaj==0 then
			elseif GetTime()>sayelldelay then
				SendChatMessage(text, chat)
				sayelldelay=GetTime()+block
			end
		else
			SendChatMessage(text, chat)
			sayelldelay2=GetTime()+block
		end
	end
end
end


end

end

==> go.php?file=SayAnnouncer8.000.zip: SayAnnouncer/SayAnnouncer.lua <==
﻿function SA_OnLoad()

	sa_version=8.000

	SA_frame:RegisterEvent("CHAT_MSG_ADDON")
	SA_frame:RegisterEvent("CHAT_MSG_SAY")
	SA_frame:RegisterEvent("CHAT_MSG_INSTANCE_CHAT")
	SA_frame:RegisterEvent("CHAT_MSG_YELL")
	SA_frame:RegisterEvent("PLAYER_ENTERING_WORLD")

	sayelldelay=GetTime()
	sayelldelay2=GetTime()
	saydelayfornames=GetTime()+15
	if SA_whitelist==nil then SA_whitelist={} end

	sa_waitfilter={0,0}

end


function SA_OnUpdate()

if GetTime()>saydelayfornames then
saydelayfornames=nil

local num=GetNumGuildMembers()
for i=1,num do
	local name, rank, rankIndex=GetGuildRosterInfo(i)
	if (rankIndex==0 or rankIndex==1) and name then
		local bil=0
		for j=1,#SA_whitelist do
			if string.lower(SA_whitelist[j])==string.lower(name) then
				bil=1
			end
		end
		if bil==0 then
			table.insert(SA_whitelist,name)
		end
	end
end
end
end


function SA_OnEvent(self,event,...)

local arg1, arg2, arg3,arg4 = ...

if event=="PLAYER_ENTERING_WORLD" then
if type(C_ChatInfo.RegisterAddonMessagePrefix) == "function" then
C_ChatInfo.RegisterAddonMessagePrefix ("SAver")
C_ChatInfo.RegisterAddonMessagePrefix ("SAYell")
end
end

if event == "CHAT_MSG_SAY" then
if arg2 and arg2==UnitName("player") then
	sa_waitfilter[1]=GetTime()+1.5
end
end

if event == "CHAT_MSG_YELL" then
if arg2 and arg2==UnitName("player") then
	sa_waitfilter[2]=GetTime()+1.5
end
end

if event == "CHAT_MSG_ADDON" then

if arg1=="SAver" and arg4 then
local bil=0
C_ChatInfo.SendAddonMessage("SAver2", bil..sa_version, "WHISPER", arg4)
end

if arg1=="SAYell" and arg3=="WHISPER" and GetTime()>sayelldelay then
local bilname=0
for i=1,#SA_whitelist do
	if string.lower(SA_whitelist[i])==string.lower(arg4) then
		bilname=1
	end
end

if bilname==0 then
	for i = 1,GetNumGroupMembers() do local name,rank = GetRaidRosterInfo(i)
		if (rank > 0 and arg2==name) then
			bilname=1
		end
	end
end

local _,a2=IsInInstance()
if arg2 and bilname==1 and a2 and a2=="raid" and UnitInRaid(arg4) and UnitAffectingCombat("player") then
	local text=""
	local chat=""
	local block=0
	local vaj=0
	if string.find(arg2, "+0!") then
		text=string.sub(arg2,1,string.find(arg2,"+0!")-1)
	end
	if string.find(arg2, "+1!") then
		chat=string.sub(arg2,string.find(arg2,"+0!")+3,string.find(arg2,"+1!")-1)
	end
	if string.find(arg2, "+2!") then
		block=tonumber(string.sub(arg2,string.find(arg2,"+1!")+3,string.find(arg2,"+2!")-1))
	end
	if string.find(arg2, "+3!") then
		vaj=tonumber(string.sub(arg2,string.find(arg2,"+2!")+3,string.find(arg2,"+3!")-1))
	end
	if string.len(text)>1 and string.len(chat)>1 then
		if chat=="say" or chat=="yell" then
			if ((chat=="say" and GetTime()<sa_waitfilter[1]) or (chat=="yell" and GetTime()<sa_waitfilter[2])) and vaj==0 then
			elseif GetTime()>sayelldelay then
				SendChatMessage(text, chat)
				sayelldelay=GetTime()+block
			end
		else
			SendChatMessage(text, chat)
			sayelldelay2=GetTime()+block
		end
	end
end
end


end

end
